@@ -60,6 +60,13 @@ import java.util.HashMap;
  */
 public interface ICache {
 
+    /**The UID of the cache can be used to distinguish between
+     *  different cache instances in order ro decide, if
+     *  e.g. remote requests should be performed or not.
+     * @return uid The UID of the cache implementation
+     */
+    public String getUID();
+
     /**
      * Creates a new ICacheEntry instance to work with and to
      * possibly add to the cache via <code>addCacheEntry</code>.
