@@ -47,10 +47,8 @@
  *
  */
 
-
 package com.openexchange.documentconverter;
 
-
 //-------------
 //- JobStatus -
 //-------------
@@ -61,12 +59,14 @@ package com.openexchange.documentconverter;
  * @author <a href="mailto:kai.ahrens@open-xchange.com">Kai Ahrens</a>
  */
 public enum JobError {
-    NONE			(JobError.ERRORCODE_NONE),
-    GENERAL			(JobError.ERRORCODE_GENERAL),
-    TIMEOUT			(JobError.ERRORCODE_TIMEOUT),
-    PASSWORD		(JobError.ERRORCODE_PASSWORD),
-    NO_CONTENT		(JobError.ERRORCODE_NO_CONTENT),
-    MAX_SOURCESIZE	(JobError.ERRORCODE_MAX_SOURCESIZE);
+    NONE(JobError.ERRORCODE_NONE),
+    GENERAL(JobError.ERRORCODE_GENERAL),
+    TIMEOUT(JobError.ERRORCODE_TIMEOUT),
+    PASSWORD(JobError.ERRORCODE_PASSWORD),
+    NO_CONTENT(JobError.ERRORCODE_NO_CONTENT),
+    MAX_SOURCESIZE(JobError.ERRORCODE_MAX_SOURCESIZE),
+    DISPOSED(JobError.ERRORCODE_DISPOSED),
+    UNSUPPORTED(JobError.ERRORCODE_UNSUPPORTED);
 
     /**
      * @param errorCode
@@ -90,19 +90,51 @@ public enum JobError {
         JobError ret = NONE;
 
         switch (errorCode) {
-        case ERRORCODE_NONE: 			ret = NONE; break;
-        case ERRORCODE_GENERAL: 		ret = GENERAL; break;
-        case ERRORCODE_TIMEOUT: 		ret = TIMEOUT; break;
-        case ERRORCODE_PASSWORD: 		ret = PASSWORD; break;
-        case ERRORCODE_NO_CONTENT: 		ret = NO_CONTENT; break;
-        case ERRORCODE_MAX_SOURCESIZE: 	ret = MAX_SOURCESIZE; break;
+            case ERRORCODE_NONE:
+                ret = NONE;
+                break;
+            case ERRORCODE_GENERAL:
+                ret = GENERAL;
+                break;
+            case ERRORCODE_TIMEOUT:
+                ret = TIMEOUT;
+                break;
+            case ERRORCODE_PASSWORD:
+                ret = PASSWORD;
+                break;
+            case ERRORCODE_NO_CONTENT:
+                ret = NO_CONTENT;
+                break;
+            case ERRORCODE_MAX_SOURCESIZE:
+                ret = MAX_SOURCESIZE;
+                break;
 
-        default: 						ret = GENERAL; break;
+            case ERRORCODE_DISPOSED:
+                ret = DISPOSED;
+                break;
+
+            case ERRORCODE_UNSUPPORTED:
+                ret = UNSUPPORTED;
+                break;
+
+            default:
+                ret = GENERAL;
+                break;
         }
 
         return ret;
     }
 
+    /**
+     * @param resultCodeNumberObj
+     * @return
+     */
+    public static JobError fromObject(Object resultCodeNumberObj) {
+        return ((null != resultCodeNumberObj) && (resultCodeNumberObj instanceof Number)) ?
+            fromErrorCode(((Number) resultCodeNumberObj).intValue()) :
+                JobError.NONE;
+    }
+
     // - Members ---------------------------------------------------------------
 
     protected int m_errorCode = ERRORCODE_NONE;
@@ -110,10 +142,12 @@ public enum JobError {
     // - Constants -------------------------------------------------------------
 
     // the error codes to be mapped to enums and vice versa
-    final protected static int ERRORCODE_NONE 			= 0x00000000;
-    final protected static int ERRORCODE_GENERAL 		= 0x00000001;
-    final protected static int ERRORCODE_TIMEOUT 		= 0x00000002;
-    final protected static int ERRORCODE_PASSWORD 		= 0x00000004;
-    final protected static int ERRORCODE_NO_CONTENT 	= 0x00000008;
+    final protected static int ERRORCODE_NONE           = 0x00000000;
+    final protected static int ERRORCODE_GENERAL        = 0x00000001;
+    final protected static int ERRORCODE_TIMEOUT        = 0x00000002;
+    final protected static int ERRORCODE_PASSWORD       = 0x00000004;
+    final protected static int ERRORCODE_NO_CONTENT     = 0x00000008;
     final protected static int ERRORCODE_MAX_SOURCESIZE = 0x00000010;
+    final protected static int ERRORCODE_DISPOSED       = 0x00000020;
+    final protected static int ERRORCODE_UNSUPPORTED    = 0x00000040;
 }
