@@ -502,7 +502,7 @@ public abstract class ManagerBasics implements ILogProvider {
                     message = e.getClass().getName();
                 }
 
-                logImpl(logProvider, LogType.LOGTYPE_ERROR, "Documentconverter caught an exception: \n" + message, null);
+                logImpl(logProvider, LogType.LOGTYPE_ERROR, "DC caught an exception: \n" + message, null);
             }
         }
     }
