@@ -97,7 +97,7 @@ public class Properties {
 
     static final public String PROP_FILTER_SHORT_NAME = "FilterShortName"; // String
 
-    static final public String PROP_IMANAGER = "IManager"; // IManager
+    static final public String PROP_IDOCUMENTCONVERTER = "IDocumentConverter"; // IDocumentConverter
 
     static final public String PROP_PIXEL_X = "PixelX"; // Integer
 
@@ -155,17 +155,13 @@ public class Properties {
 
     static final public String PROP_ASYNC = "Async"; // Boolean
 
-    static final public String PROP_IMAGE_FORMAT = "ImageFormat"; // String
+    static final public String PROP_REMOTE_ASYNC = "RemoteAsync"; // Boolean
 
-    static final public String PROP_IMAGE_TRANSFORMATIONS = "ImageTransformations"; // ImageServerTransformations
-
-    static final public String PROP_IMAGE_TRANSFORMATION_SOURCE = "ImageTransformationSource"; // Object
-
-    static final public String PROP_IMAGE_RESOLUTION = "ImageResolution"; // Integer
+    static final public String PROP_QUERY_AVAILABILITY = "QueryAvailability"; // Boolean
 
     static final public String PROP_IMAGE_SCALE_TYPE = "ImageScaleType"; // String
 
-    static final public String PROP_IMAGE_SHRINK_ONLY = "ImageShrinkOnly"; // String
+    static final public String PROP_IMAGE_RESOLUTION = "ImageResolution"; // Integer
 
     // -------------------------------------------------------------------------
 
@@ -207,14 +203,6 @@ public class Properties {
 
     static final public String PROP_RESULT_CONVERTER_COOKIE = PROP_CONVERTER_COOKIE; // String
 
-    static final public String PROP_RESULT_IMAGE_DATA = PROP_RESULT_BUFFER; // byte[]
-
-    static final public String PROP_RESULT_IMAGE_FORMAT = PROP_IMAGE_FORMAT; // String
-
-    static final public String PROP_RESULT_IMAGE_WIDTH = PROP_PIXEL_WIDTH; // Integer
-
-    static final public String PROP_RESULT_IMAGE_HEIGHT = PROP_PIXEL_HEIGHT; // Integer
-
     static final public String PROP_RESULT_ASYNC = PROP_ASYNC; // Boolean
 
     // -------------------------------------------------------------------------
