@@ -51,6 +51,7 @@ package com.openexchange.documentconverter;
 
 import java.io.BufferedOutputStream;
 import java.io.DataOutputStream;
+import java.io.File;
 import java.io.IOException;
 import java.io.InputStream;
 import java.io.ObjectOutputStream;
@@ -61,6 +62,7 @@ import java.io.Serializable;
 import java.net.HttpURLConnection;
 import java.net.URL;
 import java.util.StringTokenizer;
+import org.apache.commons.io.FileUtils;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
@@ -72,6 +74,11 @@ import org.slf4j.LoggerFactory;
  */
 public class TransferHelper {
 
+    public enum PostFormDataMode {
+        BYTEARRAY_OBJECT,
+        FILE_LENGTH_AND_DATA;
+    }
+
     /**
      * Initializes a new {@link TransferHelper}.
      */
@@ -125,7 +132,7 @@ public class TransferHelper {
                         }
                     }
                 } else if (LOG.isTraceEnabled()) {
-                    LOG.trace("Documentconverter could not open remote HTTPConnection: " + remoteUrl.toString());
+                    LOG.trace("DC could not open remote HTTPConnection: " + remoteUrl.toString());
                 }
             } catch (final Exception excp) {
                 if (excp instanceof IOException) {
@@ -145,7 +152,9 @@ public class TransferHelper {
      * @param remoteUrl
      * @param transferObj
      */
-    public static void postFormData(ManagerBasics manager, URL remoteUrl, ServerType serverType, TransferObject<? extends Serializable> transferObj, TransferResponseProcessor responseProcessor) {
+    public static void postFormData(ManagerBasics manager, URL remoteUrl, ServerType serverType, TransferObject<? extends Serializable> transferObj,
+        PostFormDataMode postFormDataMode, TransferResponseProcessor responseProcessor) {
+
         if ((null != remoteUrl) && (null != transferObj)) {
             HttpURLConnection connection = null;
 
@@ -179,7 +188,7 @@ public class TransferHelper {
                         writeParamMap(printWriter, transferObj, partSeparator);
                         printWriter.flush();
 
-                        writeFileContent(printWriter, bufferedOutputStm, transferObj, partSeparator);
+                        writeFileContent(printWriter, bufferedOutputStm, transferObj, partSeparator, postFormDataMode);
                         printWriter.flush();
 
                         // mark end of multipart/form-data
@@ -277,10 +286,12 @@ public class TransferHelper {
      * @param transferObject
      * @param partSeparator
      */
-    private static void writeFileContent(PrintWriter printWriter, OutputStream outputStm, TransferObject<? extends Serializable> transferObject, String partSeparator) throws IOException {
-        final Object serialObject = transferObject.getSerialObject();
+    private static void writeFileContent(PrintWriter printWriter, OutputStream outputStm, TransferObject<? extends Serializable> transferObject,
+        String partSeparator, PostFormDataMode postFormDataMode) throws IOException {
 
-        if (null != serialObject) {
+        final Object contentSerializable = transferObject.getSerialObject();
+
+        if (null != contentSerializable) {
             // write content part header
             printWriter.append(partSeparator);
             printWriter.append(
@@ -292,7 +303,27 @@ public class TransferHelper {
             printWriter.append("Content-Transfer-Encoding: binary").append(FDATA_CRLF).append(FDATA_CRLF).flush();
 
             final ObjectOutputStream objectOutputStm = new ObjectOutputStream(outputStm);
-            objectOutputStm.writeObject(serialObject);
+
+            // write data in different ways
+            if (contentSerializable instanceof File) {
+                final File dataFile = (File) contentSerializable;
+
+                if (PostFormDataMode.FILE_LENGTH_AND_DATA == postFormDataMode) {
+                    // write number of content bytes to write/read first
+                    objectOutputStm.writeObject(Long.valueOf(dataFile.length()));
+                    objectOutputStm.flush();
+
+                    // copy content of data file as sequence of bytes into the output stream
+                    FileUtils.copyFile(dataFile, objectOutputStm);
+                } else {
+                    // write content of data file as byte array object
+                    objectOutputStm.writeObject(FileUtils.readFileToByteArray(dataFile));
+                }
+
+            } else {
+                objectOutputStm.writeObject(contentSerializable);
+            }
+
             objectOutputStm.flush();
 
             printWriter.append(FDATA_CRLF).flush();
